@import url('https://fonts.googleapis.com/css?family=Roboto');

td, tr {
    padding-right: 1px;
    padding-left: 1px;
}

.tight {
    padding: 3px 3px;
}

.tighter {
    padding: 1px 1px;
}

.text-small {
    font-size: .75em;
}

.text-normal {
    font-size: 1em;
}

.text-right {
    text-align: right;
}

.text-center {
    text-align: center;
}

.info {
    color: red;
}

.part-list {
    white-space: nowrap;
}